==========
Contribute
==========

To make changes in this repository, open a pull request. To prioritize the import
of a new image send an email to `info@osism.tech` with reference to the created
pull request.

After creating a PR, please check the result of the GitHub Actions and correct any
errors identified.
